@@ -4,46 +4,34 @@ import uuid
 import tarfile
 import zipfile
 from time import sleep
+from uuid import uuid4
+import sanic.request
+import sanic.response
+from sanic.exceptions import Forbidden
+from sanic import Sanic
+from .config import CONFIG
+from . import tasks
+from subprocess import call
+from multiprocessing import Process
+import asyncio
+import sqlite3
+from contextlib import contextmanager
+import string
+import secrets
+import json
+import hmac
+import hashlib
+import markdown2
+import socket
+from itsdangerous import Signer
+from itsdangerous.exc import BadSignature
+from shutil import rmtree, make_archive
+from unicodedata import normalize
+from pathlib import Path
+import re
+import aiofiles
 
-version = "0.0.40"
-
-try:
-    from uuid import uuid4
-    import sanic.request
-    import sanic.response
-    from sanic.exceptions import Forbidden
-    from sanic import Sanic
-    from .config import CONFIG
-    from . import tasks
-    from subprocess import call, Popen
-    from multiprocessing import Process
-    import asyncio
-    import sqlite3
-    from contextlib import contextmanager
-    import string
-    import secrets
-    import json
-    import hmac
-    import hashlib
-    import markdown2
-    import socket
-    from itsdangerous import Signer
-    from itsdangerous.exc import BadSignature
-    from shutil import rmtree, make_archive
-    from unicodedata import normalize
-    from pathlib import Path
-    import re
-    import aiofiles
-    import logging
-    import tempfile
-    from pythonjsonlogger import jsonlogger
-except ModuleNotFoundError as e:
-    sys.exit("Import error: {}. Please refer to the documentation.".format(e))
-
-try:
-    assert sys.version_info >= (3, 6)
-except AssertionError:
-    sys.exit("Please update your python (>= 3.6)")
+version = "0.0.41"
 
 AUTH_DB_PATH = "{}/auth.db".format(CONFIG["CIRCE_WORKING_DIR"])
 
