@@ -21,6 +21,8 @@ CONFIG = {
     "CIRCE_WEB_UI_REMOVE_USER_FILES_DELAY": 7200,
     "CIRCE_TRANSFORMATIONS_MODULE": None,
     "CIRCE_UPDATE_NOTIFY_ROUTE": False,
+    "CIRCE_TEMP_DIR": None,
+    "ALLOWED_WEBHOOK_HOSTS": [],
 }
 
 for key in CONFIG.keys():
@@ -37,6 +39,9 @@ for key in CONFIG.keys():
             CONFIG[key] = True if val == "1" else False
         elif key in ["CIRCE_PORT"]:
             CONFIG[key] = int(val)
+        elif key == "ALLOWED_WEBHOOK_HOSTS":
+            CONFIG[key] = val.split(",")
+            pass
         else:
             CONFIG[key] = val
     except KeyError:
@@ -54,10 +59,14 @@ if (
 if CONFIG["CIRCE_IMMEDIATE_MODE"]:
     CONFIG["CIRCE_WORKERS"] = 1
 
+if not CONFIG["CIRCE_TEMP_DIR"]:
+    CONFIG["CIRCE_TEMP_DIR"] = "{}/tmp/".format(CONFIG["CIRCE_WORKING_DIR"])
+
 paths = [
     CONFIG["CIRCE_WORKING_DIR"],
     "{}/queue/".format(CONFIG["CIRCE_WORKING_DIR"]),
     "{}/done/".format(CONFIG["CIRCE_WORKING_DIR"]),
+    CONFIG["CIRCE_TEMP_DIR"],
 ]
 for path in paths:
     os.makedirs(path, exist_ok=True)
